
package it.finanze.dogane.accise.metano.model;

import java.io.IOException;
import java.math.BigInteger;


public class MetanoAcquistatoDaSoggettiSenzaImpianti extends MetanoRecord {
	
	private String letteraIdQuadro = "C";	
	private BigInteger tipoRigo = BigInteger.valueOf(0);	
	private BigInteger metanoDiProprieta = BigInteger.valueOf(0);	
	private String codiceAccisaFornitoreNazionale = "";	
	private BigInteger metanoFornitoreNazionale = BigInteger.valueOf(0);	
	private String codiceAccisaFornitoreUE = "";	
	private BigInteger metanoFornitoreUE = BigInteger.valueOf(0);
	private String statoEsteroMetanoFornitoreExtraUE = "";
	private BigInteger metanoFornitoreExtraUE = BigInteger.valueOf(0);
	private BigInteger totale = BigInteger.valueOf(0);
	
	public static final int dimLetteraIdQuadro = 1;	
	public static final int dimTipoRigo = 1;
	public static final int dimMetanoDiProprieta = 13;	
	public static final int dimCodiceAccisaFornitoreNazionale = 9	;
	public static final int dimMetanoFornitoreNazionale = 13;		
	public static final int dimCodiceAccisaFornitoreUE = 20;
	public static final int dimMetanoFornitoreUE = 13;
	public static final int dimStatoEsteroMetanoFornitoreExtraUE = 20;
	public static final int dimMetanoFornitoreExtraUE = 13;
	public static final int dimTotale = 13;
	
	
	public static MetanoAcquistatoDaSoggettiSenzaImpianti getNewObject(ProspettoConsumo prospettoConsumo) {
		MetanoAcquistatoDaSoggettiSenzaImpianti retvalue = new MetanoAcquistatoDaSoggettiSenzaImpianti();
		  Frontespizio frontespizio = prospettoConsumo.getFrontespizio();
		
		  retvalue.setAnnoDichiarazione(frontespizio.getAnnoDichiarazione());
		  retvalue.setCodiceAccisa(frontespizio.getCodiceAccisa());
		  retvalue.setMese(frontespizio.getMese());
	 
		  return retvalue;
		}
	
	
	
	public void scriviOggetto(java.io.OutputStream out) throws IOException {
		
			super.scriviOggetto(out);

			out.write(normalizzaCampo(letteraIdQuadro, dimLetteraIdQuadro));			
			out.write(normalizzaCampo(tipoRigo, dimTipoRigo));
			out.write(normalizzaCampo(metanoDiProprieta, dimMetanoDiProprieta));
			out.write(normalizzaCampo(codiceAccisaFornitoreNazionale, dimCodiceAccisaFornitoreNazionale));		
			out.write(normalizzaCampo(metanoFornitoreNazionale, dimMetanoFornitoreNazionale));
			out.write(normalizzaCampo(codiceAccisaFornitoreUE, dimCodiceAccisaFornitoreUE));			
			out.write(normalizzaCampo(metanoFornitoreUE, dimMetanoFornitoreUE));
		    out.write(normalizzaCampo(statoEsteroMetanoFornitoreExtraUE, dimStatoEsteroMetanoFornitoreExtraUE));		
			out.write(normalizzaCampo(metanoFornitoreExtraUE, dimMetanoFornitoreExtraUE));
			out.write(normalizzaCampo(totale, dimTotale));							
			
			scriviFineRiga(out);
		}

		public void leggiOggetto(java.io.InputStream in) throws IOException {
		
			super.leggiOggetto(in);
		
			letteraIdQuadro = readFieldString(in, dimLetteraIdQuadro);
			tipoRigo =readFieldBigInteger(in, dimTipoRigo);
			metanoDiProprieta = readFieldBigInteger(in, dimMetanoDiProprieta);
			codiceAccisaFornitoreNazionale =	 readFieldString(in, dimCodiceAccisaFornitoreNazionale);		
			metanoFornitoreNazionale = readFieldBigInteger(in, dimMetanoFornitoreNazionale);
			codiceAccisaFornitoreUE =	 readFieldString(in, dimCodiceAccisaFornitoreUE);	
			metanoFornitoreUE = readFieldBigInteger(in, dimMetanoFornitoreUE);
			statoEsteroMetanoFornitoreExtraUE = readFieldString(in, dimStatoEsteroMetanoFornitoreExtraUE);			
			metanoFornitoreExtraUE =	 readFieldBigInteger(in, dimMetanoFornitoreExtraUE);
			totale = readFieldBigInteger(in, dimTotale);			
		
			saltaFineRiga(in);
		}


	/**
	 * @return
	 */
	public String getCodiceAccisaFornitoreNazionale() {
		return codiceAccisaFornitoreNazionale;
	}

	/**
	 * @return
	 */
	public String getCodiceAccisaFornitoreUE() {
		return codiceAccisaFornitoreUE;
	}

	/**
	 * @return
	 */
	public String getLetteraIdQuadro() {
		return letteraIdQuadro;
	}

	/**
	 * @return
	 */
	public BigInteger getMetanoDiProprieta() {
		return metanoDiProprieta;
	}

	/**
	 * @return
	 */
	public BigInteger  getMetanoFornitoreExtraUE() {
		return metanoFornitoreExtraUE;
	}

	/**
	 * @return
	 */
	public BigInteger  getMetanoFornitoreNazionale() {
		return metanoFornitoreNazionale;
	}

	/**
	 * @return
	 */
	public BigInteger  getMetanoFornitoreUE() {
		return metanoFornitoreUE;
	}

	/**
	 * @return
	 */
	public String getStatoEsteroMetanoFornitoreExtraUE() {
		return statoEsteroMetanoFornitoreExtraUE;
	}

	/**
	 * @return
	 */
	public BigInteger  getTipoRigo() {
		return tipoRigo;
	}

	/**
	 * @return
	 */
	public BigInteger  getTotale() {
		return totale;
	}

	/**
	 * @param string
	 */
	public void setCodiceAccisaFornitoreNazionale(String string) {
		codiceAccisaFornitoreNazionale = string;
	}

	/**
	 * @param string
	 */
	public void setCodiceAccisaFornitoreUE(String string) {
		codiceAccisaFornitoreUE = string;
	}

	/**
	 * @param string
	 */
	public void setLetteraIdQuadro(String string) {
		letteraIdQuadro = string;
	}

	/**
	 * @param string
	 */
	public void setMetanoDiProprieta(BigInteger  intero) {
		metanoDiProprieta = intero;
	}

	/**
	 * @param string
	 */
	public void setMetanoFornitoreExtraUE(BigInteger  intero) {
		metanoFornitoreExtraUE = intero;
	}

	/**
	 * @param string
	 */
	public void setMetanoFornitoreNazionale(BigInteger  intero ) {
		metanoFornitoreNazionale = intero;
	}
	
	public void setTipoRecord(BigInteger i) {
			super.setTipoRecord(i);
			setLetteraIdQuadro("C");
		}

	/**
	 * @param string
	 */
	public void setMetanoFornitoreUE(BigInteger  intero) {
		metanoFornitoreUE = intero;
	}

	/**
	 * @param string
	 */
	public void setStatoEsteroMetanoFornitoreExtraUE(String string) {
		statoEsteroMetanoFornitoreExtraUE = string;
	}

	/**
	 * @param i
	 */
	public void setTipoRigo(BigInteger  i) {
		tipoRigo = i;
	}

	/**
	 * @param i
	 */
	public void setTotale(BigInteger  i) {
		totale = i;
	}
	
	public Object clone() throws CloneNotSupportedException {
			MetanoAcquistatoDaSoggettiSenzaImpianti clonato = new MetanoAcquistatoDaSoggettiSenzaImpianti();
			
			clonato.setAnnoDichiarazione(this.getAnnoDichiarazione());			
			clonato.setCodiceAccisa(this.getCodiceAccisa());
			clonato.setLetteraIdQuadro(this.getLetteraIdQuadro());
			clonato.setTipoRigo(this.getTipoRigo());
			clonato.setTipoRecord(this.getTipoRecord());
			clonato.setMese(this.getMese());
		    clonato.setProvincia(this.getProvincia());
			clonato.setCodiceAccisaFornitoreNazionale(this.getCodiceAccisaFornitoreNazionale());
		    clonato.setMetanoFornitoreNazionale(this.getMetanoFornitoreNazionale());
		    clonato.setMetanoDiProprieta(this.getMetanoDiProprieta());
		    clonato.setCodiceAccisaFornitoreUE(this.getCodiceAccisaFornitoreUE());
		    clonato.setMetanoFornitoreUE(this.getMetanoFornitoreUE());
		    clonato.setStatoEsteroMetanoFornitoreExtraUE(this.getStatoEsteroMetanoFornitoreExtraUE());
		    clonato.setMetanoFornitoreExtraUE(this.getMetanoFornitoreExtraUE());
		    clonato.setTotale(this.getTotale());
			return clonato;
		}
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	

}
