

package it.finanze.dogane.accise.metano.model;

import java.io.IOException;
import java.math.BigInteger;


public class MetanoEstrattoVenduto extends MetanoRecord{
	
	private String letteraIdQuadro = "";	
	private BigInteger tipoRigo = BigInteger.valueOf(0);
	private String tipEstrazioneVendita = "";
	private String codiceAcc = "";
	private BigInteger metriCubi = BigInteger.valueOf(0);	
	
	public static final int dimLetteraIdQuadro = 1;	
	public static final int dimTipoRigo = 1;
	public static final int dimTipEstrazioneVendita = 1;
	public static final int dimCodiceAccisa = 20;	
	public static final int dimMetriCubi = 13;
	
	private String letteraQuadro = null;
	
	
	public static MetanoEstrattoVenduto getNewObject(ProspettoConsumo prospettoConsumo) {
	  MetanoEstrattoVenduto retvalue = new MetanoEstrattoVenduto();
	  Frontespizio frontespizio = prospettoConsumo.getFrontespizio();
		
	  retvalue.setAnnoDichiarazione(frontespizio.getAnnoDichiarazione());
	  retvalue.setCodiceAccisa(frontespizio.getCodiceAccisa());
	  retvalue.setMese(frontespizio.getMese());
	 
	 
	  return retvalue;
	}
	
	
	
	public void scriviOggetto(java.io.OutputStream out) throws IOException {
		
			super.scriviOggetto(out);

			out.write(normalizzaCampo(letteraIdQuadro, dimLetteraIdQuadro));
			out.write(normalizzaCampo(tipoRigo, dimTipoRigo));		;
			out.write(normalizzaCampo(tipEstrazioneVendita, dimTipEstrazioneVendita));
			out.write(normalizzaCampo(codiceAcc, dimCodiceAccisa));
			out.write(normalizzaCampo(metriCubi, dimMetriCubi));					
			
			scriviFineRiga(out);
		}		
		
	public void leggiOggetto(java.io.InputStream in) throws IOException {
		
			super.leggiOggetto(in);
		
			letteraIdQuadro = readFieldString(in, dimLetteraIdQuadro);		
		    tipoRigo = readFieldBigInteger(in, dimTipoRigo);		
		    tipEstrazioneVendita = readFieldString(in, dimTipEstrazioneVendita);		    
		    codiceAcc = readFieldString(in, dimCodiceAccisa);		
		    metriCubi =  readFieldBigInteger(in, dimMetriCubi);
		    
			saltaFineRiga(in);
		}

	
	

	/**
	 * @return
	 */
	

	/**
	 * @return
	 */
	public static int getDimLetteraIdQuadro() {
		return dimLetteraIdQuadro;
	}

	/**
	 * @return
	 */
	public static int getDimMetriCubi() {
		return dimMetriCubi;
	}

	/**
	 * @return
	 */
	public static int getDimTipEstrazioneVendita() {
		return dimTipEstrazioneVendita;
	}

	/**
	 * @return
	 */
	public static int getDimTipoRigo() {
		return dimTipoRigo;
	}

	/**
	 * @return
	 */
	public String getCodiceAcc() {
		return codiceAcc;
	}

	/**
	 * @return
	 */
	public String getLetteraIdQuadro() {
		return letteraIdQuadro;
	}

	/**
	 * @return
	 */
	public BigInteger getMetriCubi() {
		return metriCubi;
	}

	/**
	 * @return
	 */
	public String getTipEstrazioneVendita() {
		return tipEstrazioneVendita;
	}

	/**
	 * @return
	 */
	public BigInteger getTipoRigo() {
		return tipoRigo;
	}

	/**
	 * @param string
	 */
	public void setCodiceAcc(String string) {
		codiceAcc = string;
	}

	/**
	 * @param string
	 */
	public void setLetteraIdQuadro(String string) {
		letteraIdQuadro = string;
	}

	/**
	 * @param i
	 */
	public void setMetriCubi(BigInteger i) {
		metriCubi = i;
	}

	/**
	 * @param string
	 */
	public void setTipEstrazioneVendita(String string) {
		tipEstrazioneVendita = string;
	}

	/**
	 * @param i
	 */
	public void setTipoRigo(BigInteger i) {
		tipoRigo = i;
	}
	
	public void setTipoRecord(BigInteger i) {
		super.setTipoRecord(i);
		if(i.equals(BigInteger.valueOf(15))){		
		   setLetteraIdQuadro("B");
		}else if (i.equals(BigInteger.valueOf(15))){
		   setLetteraIdQuadro("D");	
	    }
	}
	
	public Object clone() throws CloneNotSupportedException {
		MetanoEstrattoVenduto clonato = new MetanoEstrattoVenduto();
		//if(letteraQuadro==null){
			//letteraQuadro = this.getLetteraIdQuadro(); 
		//}
		clonato.setCodiceAccisa(this.getCodiceAccisa());
		clonato.setAnnoDichiarazione(this.getAnnoDichiarazione());	
		clonato.setTipoRecord(this.getTipoRecord());
		clonato.setProvincia(this.getProvincia());
		clonato.setMese(this.getMese());
		clonato.setLetteraIdQuadro(this.getLetteraIdQuadro());
		clonato.setTipoRigo(this.getTipoRigo());
		clonato.setTipEstrazioneVendita(this.getTipEstrazioneVendita());			
		clonato.setCodiceAcc(this.getCodiceAcc());
		clonato.setMetriCubi(this.getMetriCubi());
		
		return clonato;
	}

}
