
package it.finanze.dogane.accise.metano.model;

import it.finanze.dogane.accise.model.AbstractRecord;

import java.io.IOException;
import java.math.BigInteger;


public class MetanoFatturatoImpiegatoSenzaPagAccisa extends MetanoRecord {
	
	private String letteraIdQuadro = "";	
	private BigInteger progIdRigo = BigInteger.valueOf(0);
	private BigInteger numUtenze = BigInteger.valueOf(0);
	private String segno = "";
	private BigInteger quantita = new BigInteger("0");
	
	
	public static final int dimLetteraIdQuadro = 1;	
	public static final int dimProgIdRigo = 2;
	public static final int dimNumUtenze = 8;
	public static final int dimSegno = 1;	
	public static final int dimQuantita = 13;

	
	public void scriviOggetto(java.io.OutputStream out) throws IOException {
		
				super.scriviOggetto(out);

				out.write(normalizzaCampo(letteraIdQuadro, dimLetteraIdQuadro));
				out.write(normalizzaCampo(progIdRigo, dimProgIdRigo));		;
				out.write(normalizzaCampo(numUtenze, dimNumUtenze));		        
				out.write(normalizzaCampo(getSegno(), dimSegno));
				out.write(normalizzaCampo(quantita, dimQuantita));					
			
				scriviFineRiga(out);
			}		
		
		public void leggiOggetto(java.io.InputStream in) throws IOException {
		
				super.leggiOggetto(in);
		
				letteraIdQuadro = readFieldString(in, dimLetteraIdQuadro);		
			    progIdRigo = readFieldBigInteger(in, dimProgIdRigo);		
			    numUtenze = readFieldBigInteger(in, dimNumUtenze);		    
			    segno = readFieldString(in, dimSegno);		
			    quantita =  readFieldBigInteger(in, dimQuantita);	
			    if(AbstractRecord.MINUS.equals(segno)) {					
					//quantita.negate();
					BigInteger quantitaNew = quantita.multiply(BigInteger.valueOf(-1));
					quantita=quantitaNew;
 				}	    
				saltaFineRiga(in);
			}


	public static MetanoFatturatoImpiegatoSenzaPagAccisa getNewObject(ProspettoConsumo prospettoConsumo) {
		 MetanoFatturatoImpiegatoSenzaPagAccisa retvalue = new MetanoFatturatoImpiegatoSenzaPagAccisa();
		  Frontespizio frontespizio = prospettoConsumo.getFrontespizio();
		
		  retvalue.setAnnoDichiarazione(frontespizio.getAnnoDichiarazione());
		  retvalue.setCodiceAccisa(frontespizio.getCodiceAccisa());
		  retvalue.setMese(frontespizio.getMese());
		  retvalue.setProvincia(frontespizio.getProvincia());
	 
	 
		  return retvalue;
		}
	
	
	

	/**
	 * @return
	 */
	public static int getDimLetteraIdQuadro() {
		return dimLetteraIdQuadro;
	}

	/**
	 * @return
	 */
	public static int getDimNumUtenze() {
		return dimNumUtenze;
	}

	/**
	 * @return
	 */
	public static int getDimProgIdRigo() {
		return dimProgIdRigo;
	}

	/**
	 * @return
	 */
	public static int getDimQuantita() {
		return dimQuantita;
	}

	/**
	 * @return
	 */
	public static int getDimSegno() {
		return dimSegno;
	}

	/**
	 * @return
	 */
	public String getLetteraIdQuadro() {
		return letteraIdQuadro;
	}

	/**
	 * @return
	 */
	public BigInteger getNumUtenze() {
		return numUtenze;
	}

	/**
	 * @return
	 */
	public BigInteger getProgIdRigo() {
		return progIdRigo;
	}

	/**
	 * @return
	 */
	public BigInteger getQuantita() {		
		
		return quantita;
	}

	/**
	 * @return
	 */
	public String getSegno() {
		String retvalue = AbstractRecord.PLUS;
		// minore di zero
		if(quantita.compareTo(BigInteger.valueOf(0))==-1) {
			retvalue = AbstractRecord.MINUS;
		}
		return retvalue;
		
	}

	/**
	 * @param string
	 */
	public void setLetteraIdQuadro(String string) {
		letteraIdQuadro = string;
	}

	/**
	 * @param string
	 */
	public void setNumUtenze(BigInteger bigInteger) {
		numUtenze = bigInteger;
	}

	/**
	 * @param i
	 */
	public void setProgIdRigo(BigInteger i) {
		progIdRigo = i;
	}

	/**
	 * @param i
	 */
	public void setQuantita(BigInteger i) {
		quantita = i;
	}
	
	public void setTipoRecord(BigInteger i) {
		super.setTipoRecord(i);
			
		   setLetteraIdQuadro("E");
		
	}
	
	
	public Object clone() throws CloneNotSupportedException {
			MetanoFatturatoImpiegatoSenzaPagAccisa clonato = new MetanoFatturatoImpiegatoSenzaPagAccisa();
			
			clonato.setCodiceAccisa(this.getCodiceAccisa());
			clonato.setAnnoDichiarazione(this.getAnnoDichiarazione());	
			clonato.setTipoRecord(this.getTipoRecord());
			clonato.setProvincia(this.getProvincia());
			clonato.setMese(this.getMese());
			
			clonato.setLetteraIdQuadro(this.getLetteraIdQuadro());
			clonato.setProgIdRigo(this.getProgIdRigo());
			clonato.setNumUtenze(this.getNumUtenze());			
			//clonato.setSegno(this.getSegno());
			clonato.setQuantita(this.getQuantita());
		
			return clonato;
		}
	
	
	
	
	
	
	
	
	
	
	
	
	

}
