package it.finanze.dogane.accise.metano.model;

import java.io.IOException;
import java.math.BigInteger;

public class MetanoIntrodottoInDepositiFiscali extends MetanoRecord {
	
	private String letteraIdQuadro = "";
	private BigInteger progPuntoImmissione = BigInteger.valueOf(0);
	private BigInteger tipoRigo = BigInteger.valueOf(0);
	private BigInteger metanoPropriPozzi = BigInteger.valueOf(0);
	private BigInteger metanoAltreFonti = BigInteger.valueOf(0);
	private String codiceAccisaFornitoreNazionale = "";
	private BigInteger metanoFornitoreNazionale = BigInteger.valueOf(0);
	private String codiceAccisaFornitoreUE = "";
	private BigInteger metanoFornitoreUE = BigInteger.valueOf(0);
	private BigInteger metanoFornitoreExtraUE = BigInteger.valueOf(0);
	private BigInteger totale = BigInteger.valueOf(0);
	private String comunePuntoImmissione = "";
	private String provinciaPuntoImmissione = "";
	private String indirizzoPuntoImmissione = "";
	
		
	
	public static final int dimLetteraIdQuadro = 1;	
	public static final int dimProgPuntoImmissione = 3;
	public static final int dimTipoRigo = 1;
	public static final int dimMetanoPropriPozzi = 13;	
	public static final int dimMetanoAltreFonti = 13;
	public static final int dimCodiceAccisaFornitoreNazionale = 9	;
	public static final int dimMetanoFornitoreNazionale = 13;	
	public static final int dimCodiceAccisaFornitoreUE = 20;
	public static final int dimMetanoFornitoreUE = 13;
	public static final int dimMetanoFornitoreExtraUE = 13;
	public static final int dimTotale = 13;
	public static final int dimComunePuntoImmissione = 45;
	public static final int dimProvinciaPuntoImmissione = 2;
	public static final int dimIndirizzoPuntoImmissione = 50;
	
	
	public void scriviOggetto(java.io.OutputStream out) throws IOException {
		
		super.scriviOggetto(out);

		out.write(normalizzaCampo(letteraIdQuadro, dimLetteraIdQuadro));
		out.write(normalizzaCampo(progPuntoImmissione, dimProgPuntoImmissione));		;
		out.write(normalizzaCampo(tipoRigo, dimTipoRigo));
		out.write(normalizzaCampo(metanoPropriPozzi, dimMetanoPropriPozzi));
		out.write(normalizzaCampo(metanoAltreFonti, dimMetanoAltreFonti));
		out.write(normalizzaCampo(codiceAccisaFornitoreNazionale, dimCodiceAccisaFornitoreNazionale));		
		out.write(normalizzaCampo(metanoFornitoreNazionale, dimMetanoFornitoreNazionale));
		out.write(normalizzaCampo(codiceAccisaFornitoreUE, dimCodiceAccisaFornitoreUE));
		out.write(normalizzaCampo(metanoFornitoreUE, dimMetanoFornitoreUE));		
		out.write(normalizzaCampo(metanoFornitoreExtraUE, dimMetanoFornitoreExtraUE));
		out.write(normalizzaCampo(totale, dimTotale));
		if(tipoRigo.equals(BigInteger.ZERO)) {
			out.write(normalizzaCampo(comunePuntoImmissione, dimComunePuntoImmissione));
			out.write(normalizzaCampo(provinciaPuntoImmissione, dimProvinciaPuntoImmissione));
			out.write(normalizzaCampo(indirizzoPuntoImmissione, dimIndirizzoPuntoImmissione));
		}		
		scriviFineRiga(out);
	}

	public void leggiOggetto(java.io.InputStream in) throws IOException {
		
		super.leggiOggetto(in);
		
		letteraIdQuadro = readFieldString(in, dimLetteraIdQuadro);		
		progPuntoImmissione = readFieldBigInteger(in, dimProgPuntoImmissione);		
		tipoRigo = readFieldBigInteger(in, dimTipoRigo);
		metanoPropriPozzi =	 readFieldBigInteger(in, dimMetanoPropriPozzi);		
		metanoAltreFonti = readFieldBigInteger(in, dimMetanoAltreFonti);
		codiceAccisaFornitoreNazionale =	 readFieldString(in, dimCodiceAccisaFornitoreNazionale);		
		metanoFornitoreNazionale = readFieldBigInteger(in, dimMetanoFornitoreNazionale);
		codiceAccisaFornitoreUE =	 readFieldString(in, dimCodiceAccisaFornitoreUE);	
		metanoFornitoreUE = readFieldBigInteger(in, dimMetanoFornitoreUE);
		metanoFornitoreExtraUE =	 readFieldBigInteger(in, dimMetanoFornitoreExtraUE);
		totale = readFieldBigInteger(in, dimTotale);
		if(tipoRigo.equals(BigInteger.ZERO)) {
			comunePuntoImmissione = readFieldString(in, dimComunePuntoImmissione);
			provinciaPuntoImmissione =readFieldString(in, dimProvinciaPuntoImmissione);
			indirizzoPuntoImmissione = readFieldString(in, dimIndirizzoPuntoImmissione);
		}
		
		saltaFineRiga(in);
	}

	
	public static MetanoIntrodottoInDepositiFiscali getNewObject(ProspettoConsumo prospettoConsumo) {
	MetanoIntrodottoInDepositiFiscali retvalue = new MetanoIntrodottoInDepositiFiscali();
	  Frontespizio frontespizio = prospettoConsumo.getFrontespizio();
		
	  retvalue.setAnnoDichiarazione(frontespizio.getAnnoDichiarazione());
	  retvalue.setCodiceAccisa(frontespizio.getCodiceAccisa());
	  retvalue.setMese(frontespizio.getMese());
	  retvalue.setTipoRecord(BigInteger.valueOf(10));
	 
	  return retvalue;
	}
	
	

	

	/**
	 * @return
	 */
	public String getCodiceAccisaFornitoreNazionale() {
		return codiceAccisaFornitoreNazionale;
	}

	/**
	 * @return
	 */
	public String getCodiceAccisaFornitoreUE() {
		return codiceAccisaFornitoreUE;
	}

	/**
	 * @return
	 */
	public String getComunePuntoImmissione() {
		return comunePuntoImmissione;
	}

	/**
	 * @return
	 */
	public String getIndirizzoPuntoImmissione() {
		return indirizzoPuntoImmissione;
	}

	/**
	 * @return
	 */
	public String getLetteraIdQuadro() {
		return letteraIdQuadro;
	}


	/**
	 * @return
	 */
	public BigInteger getProgPuntoImmissione() {
		return progPuntoImmissione;
	}

	/**
	 * @return
	 */
	public String getProvincia() {
		return provinciaPuntoImmissione;
	}

	/**
	 * @return
	 */
	public BigInteger getTipoRigo() {
		return tipoRigo;
	}

	/**
	 * @return
	 */
	public BigInteger getTotale() {
		return totale;
	}

	/**
	 * @param string
	 */
	public void setCodiceAccisaFornitoreNazionale(String string) {
		codiceAccisaFornitoreNazionale = string;
	}

	/**
	 * @param string
	 */
	public void setCodiceAccisaFornitoreUE(String string) {
		codiceAccisaFornitoreUE = string;
	}

	/**
	 * @param string
	 */
	public void setComunePuntoImmissione(String string) {
		comunePuntoImmissione = string;
	}

	/**
	 * @param string
	 */
	public void setIndirizzoPuntoImmissione(String string) {
		indirizzoPuntoImmissione = string;
	}

	/**
	 * @param string
	 */
	public void setLetteraIdQuadro(String string) {
		letteraIdQuadro = string;
	}

	/**
	 * @param i
	 */
	public void setProgPuntoImmissione(BigInteger i) {
		progPuntoImmissione = i;
	}

	/**
	 * @param string
	 */
	public void setProvincia(String string) {
		provinciaPuntoImmissione = string;
	}

	/**
	 * @param i
	 */
	public void setTipoRigo(BigInteger i) {
		tipoRigo = i;
	}

	/**
	 * @param i
	 */
	public void setTotale(BigInteger i) {
		totale = i;
	}
	
	/**
	 * Ridefinisco il metodo per impostare la lettera identificativa del quadro
	 */
	public void setTipoRecord(BigInteger i) {
		super.setTipoRecord(i);
		
		setLetteraIdQuadro("A");
	}
	
	public Object clone() throws CloneNotSupportedException {
			MetanoIntrodottoInDepositiFiscali clonato = new MetanoIntrodottoInDepositiFiscali();
			
			clonato.setCodiceAccisa(this.getCodiceAccisa());
			clonato.setAnnoDichiarazione(this.getAnnoDichiarazione());	
			clonato.setTipoRecord(this.getTipoRecord());
			clonato.setProvincia(this.getProvincia());
			clonato.setMese(this.getMese());
			
			clonato.setLetteraIdQuadro(this.getLetteraIdQuadro());
		    clonato.setProgPuntoImmissione(this.getProgPuntoImmissione());
			clonato.setTipoRigo(this.getTipoRigo());
			clonato.setMetanoAltreFonti(this.getMetanoAltreFonti());			
			clonato.setMetanoFornitoreExtraUE(this.getMetanoFornitoreExtraUE());
			clonato.setMetanoFornitoreNazionale(this.getMetanoFornitoreNazionale());
		    clonato.setMetanoFornitoreUE(this.getMetanoFornitoreUE());
		    clonato.setMetanoPropriPozzi(this.getMetanoPropriPozzi());
		    clonato.setCodiceAccisaFornitoreUE(this.getCodiceAccisaFornitoreUE());
	   	    clonato.setCodiceAccisaFornitoreNazionale(this.getCodiceAccisaFornitoreNazionale());
	   	    clonato.setTotale(this.getTotale());
			clonato.setComunePuntoImmissione(this.getComunePuntoImmissione());
		    clonato.setProvincia(this.getProvincia());
		    clonato.setIndirizzoPuntoImmissione(this.getIndirizzoPuntoImmissione());
		
			return clonato;
		}

	/**
	 * @return
	 */
	public BigInteger getMetanoAltreFonti() {
		return metanoAltreFonti;
	}

	/**
	 * @return
	 */
	public BigInteger getMetanoFornitoreExtraUE() {
		return metanoFornitoreExtraUE;
	}

	/**
	 * @return
	 */
	public BigInteger getMetanoFornitoreNazionale() {
		return metanoFornitoreNazionale;
	}

	/**
	 * @return
	 */
	public BigInteger getMetanoFornitoreUE() {
		return metanoFornitoreUE;
	}

	/**
	 * @return
	 */
	public BigInteger getMetanoPropriPozzi() {
		return metanoPropriPozzi;
	}

	/**
	 * @param integer
	 */
	public void setMetanoAltreFonti(BigInteger integer) {
		metanoAltreFonti = integer;
	}

	/**
	 * @param integer
	 */
	public void setMetanoFornitoreExtraUE(BigInteger integer) {
		metanoFornitoreExtraUE = integer;
	}

	/**
	 * @param integer
	 */
	public void setMetanoFornitoreNazionale(BigInteger integer) {
		metanoFornitoreNazionale = integer;
	}

	/**
	 * @param integer
	 */
	public void setMetanoFornitoreUE(BigInteger integer) {
		metanoFornitoreUE = integer;
	}

	/**
	 * @param integer
	 */
	public void setMetanoPropriPozzi(BigInteger integer) {
		metanoPropriPozzi = integer;
	}

	
	public boolean equals(Object obj) {
		MetanoIntrodottoInDepositiFiscali right = (MetanoIntrodottoInDepositiFiscali)obj;
		
		return this.getComunePuntoImmissione().equals(right.getComunePuntoImmissione()) & this.getProvincia().equals(right.getProvincia()) & this.getIndirizzoPuntoImmissione().equals(right.getIndirizzoPuntoImmissione());
	}

	public int hashCode() {
		return getComunePuntoImmissione().hashCode() | getProvincia().hashCode() | getIndirizzoPuntoImmissione().hashCode();
	}

	/**
	 * @return
	 */
	public String getProvinciaPuntoImmissione() {
		return provinciaPuntoImmissione;
	}

	/**
	 * @param string
	 */
	public void setProvinciaPuntoImmissione(String string) {
		provinciaPuntoImmissione = string;
	}

}
