package it.finanze.dogane.accise.metano.model;

import it.finanze.dogane.accise.model.AbstractRecord;

import java.io.IOException;
import java.math.BigInteger;

public abstract class MetanoRecord extends AbstractRecord {

	private static final String valoreFisso = "METANO" ;
	private String codiceAccisa = "";
	private BigInteger annoDichiarazione = BigInteger.valueOf(0);
	private BigInteger tipoRecord = BigInteger.valueOf(0);
	private String provincia = "";
	private BigInteger mese = BigInteger.valueOf(0);
	
	public static final int dimValoreFisso = 6;
	public static final int dimCodiceAccisa = 9;
	public static final int dimAnnoDichiarazione = 4;
	public static final int dimTipoRecord = 2;
	public static final int dimProvincia = 2;
	public static final int dimMese = 2;
	public static final int dimCodiceFiscale = 16;
	public static final int dimData = 10;

	public void impostaCampiComuni(AbstractRecord in) {
		MetanoRecord erin = (MetanoRecord)in;
		codiceAccisa = erin.getCodiceAccisa();
		annoDichiarazione = erin.getAnnoDichiarazione();
	}

	public void scriviOggetto(java.io.OutputStream out) throws IOException {
		
		super.scriviOggetto(out);
		out.write(normalizzaCampo(valoreFisso, dimValoreFisso));
		out.write(normalizzaCampo(codiceAccisa, dimCodiceAccisa));
		out.write(normalizzaCampo(annoDichiarazione, dimAnnoDichiarazione));
		out.write(normalizzaCampo(tipoRecord, dimTipoRecord));
		out.write(normalizzaCampo(provincia, dimProvincia));
		out.write(normalizzaCampo(mese, dimMese));
	}

	public void leggiOggetto(java.io.InputStream in) throws IOException {

		super.leggiOggetto(in);

		readFieldString(in, dimValoreFisso);		
		codiceAccisa = readFieldString(in, dimCodiceAccisa);		
		annoDichiarazione = readFieldBigInteger(in, dimAnnoDichiarazione);
		tipoRecord = readFieldBigInteger(in, dimTipoRecord);
		provincia = readFieldString(in, dimProvincia);
		mese = readFieldBigInteger(in, dimMese);
		
	}


	/**
	 * @return
	 */
	public static int getDimAnnoDichiarazione() {
		return dimAnnoDichiarazione;
	}

	/**
	 * @return
	 */
	public static int getDimCodiceAccisa() {
		return dimCodiceAccisa;
	}

	/**
	 * @return
	 */
	public static int getDimValoreFisso() {
		return dimValoreFisso;
	}

	/**
	 * @return
	 */
	public static String getValoreFisso() {
		return valoreFisso;
	}

	/**
	 * @return
	 */
	public BigInteger getAnnoDichiarazione() {
		return annoDichiarazione;
	}

	/**
	 * @return
	 */
	public String getCodiceAccisa() {
		return codiceAccisa;
	}

	/**
	 * @param i
	 */
	public void setAnnoDichiarazione(BigInteger i) {
		annoDichiarazione = i;
	}

	/**
	 * @param string
	 */
	public void setCodiceAccisa(String string) {
		codiceAccisa = string;
	}

	

	/**
	 * @return
	 */
	public static int getDimMese() {
		return dimMese;
	}

	/**
	 * @return
	 */
	public static int getDimProvincia() {
		return dimProvincia;
	}

	/**
	 * @return
	 */
	public static int getDimTipoRecord() {
		return dimTipoRecord;
	}

	

	/**
	 * @return
	 */
	public BigInteger getMese() {
		return mese;
	}

	/**
	 * @return
	 */
	public String getProvincia() {
		return provincia;
	}

	/**
	 * @return
	 */
	public BigInteger getTipoRecord() {
		return tipoRecord;
	}

	
	/**
	 * @param i
	 */
	public void setMese(BigInteger i) {
		mese = i;
	}

	/**
	 * @param string
	 */
	public void setProvincia(String string) {
		provincia = string;
	}

	/**
	 * @param i
	 */
	public void setTipoRecord(BigInteger i) {
		tipoRecord = i;
	}

}
