package it.finanze.dogane.accise.metano.model;

import it.finanze.dogane.accise.model.DicInterface;
import it.finanze.dogane.accise.model.Prospect;
import it.finanze.dogane.accise.util.ComparatorListModel;
import it.finanze.dogane.accise.util.QuadroUtil;
import it.finanze.dogane.accise.util.ResourceAccess;

import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Serializable;
import java.math.BigInteger;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

public class ProspettoInterchange extends ProspettoConsumo {

	private MetanoInterchange interchangeRecordTestata = null;
	private ResourceAccess resourceAccess = null;

	public ProspettoInterchange(ProspettoConsumo prospetto){
		super();
		interchangeRecordTestata = new MetanoInterchange();
		resourceAccess = new ResourceAccess(this);
		setResourceAccess(resourceAccess);
		setFrontespizio(prospetto.getFrontespizio());
		setListaRecord(prospetto.getListaRecord());
	}
	
	
	public void scriviOggetto(java.io.OutputStream out) throws IOException {

		updateRecordNumbers();
		// aggiorno il numero di record nel record di testata con i record presenti nel file
		interchangeRecordTestata.setNumeroRecordPresentiNelFlusso(BigInteger.valueOf(getListaRecord().size()+2));
		// scrivo il frontespizio dell'interchange
		interchangeRecordTestata.scriviOggetto(out);
		// aggiorno il frontespizio del file settando il numero di supporti a 1
		getFrontespizio().setNumeroSupporti(BigInteger.valueOf(1));
		// aggiorno il frontespizio del file
		getFrontespizio().scriviOggetto(out);
		// scrivo gli altri record
		Collections.sort(getListaRecord(), new ComparatorListModel());
		Iterator it = getListaRecord().iterator();
		while (it.hasNext()) {
			MetanoRecord record = (MetanoRecord) it.next();
			record.scriviOggetto(out);
		}
	}
	
	public Object scriviOggettoInterchange() throws IOException {
		List listaOut=new LinkedList();
		ByteArrayOutputStream out = null;
		ByteArrayOutputStream appoggio = new ByteArrayOutputStream();

		//calcolo la dimensione totale del buffer con tutti i record
		scriviOggetto(appoggio);
		BigInteger sizeFile = BigInteger.valueOf(appoggio.size());
		
		if (sizeFile.compareTo(ResourceAccess.MAX_SIZE_FILE_INTERCHANGE)==1) {
			// in tal caso il file deve essere spacchettato in pi pacchetti
			out = new ByteArrayOutputStream();

			updateRecordNumbers();

			// calcolo il numero di supporti necessari
			BigInteger numeroSupporti=sizeFile.divide(ResourceAccess.MAX_SIZE_FILE_INTERCHANGE);
			BigInteger numeroSupportiModulo=sizeFile.remainder(ResourceAccess.MAX_SIZE_FILE_INTERCHANGE);
			if (numeroSupportiModulo.compareTo(BigInteger.valueOf(0))!=0){
				numeroSupporti=numeroSupporti.add(BigInteger.valueOf(1));
			}
			// aggiorno il frontespizio del file settando il numero di supporti al valore "numeroSupporti"
			getFrontespizio().setNumeroSupporti(numeroSupporti);

			Collections.sort(getListaRecord(), new ComparatorListModel());
			Iterator it = getListaRecord().iterator();
			int count=1;
			while (it.hasNext()) {
				ByteArrayOutputStream outTmp = new ByteArrayOutputStream();
				MetanoRecord record = (MetanoRecord) it.next();
	
				// calcolo la size per il nuovo oggetto aggiunto
				record.scriviOggetto(outTmp);
				BigInteger sizeTmp = BigInteger.valueOf(outTmp.size());
				// prendo la size del buffer
				BigInteger size = BigInteger.valueOf(out.size());
				// se la size del buffer + la size del singolo record eccede MAX_SIZE_FILE_INTERCHANGE
				size = size.add(sizeTmp); 
				if (size.compareTo(ResourceAccess.MAX_SIZE_FILE_INTERCHANGE)==1) {
					// non posso ancora aggiungere il record, devo prima spacchettare il file
					ByteArrayOutputStream outFile = new ByteArrayOutputStream();
					// se sono nel primo file ho un numero di record pari a count +1
					if (listaOut.size()==0)
						count++;
					//1. aggiorno il numero di record da inserire nel file spacchettato
					interchangeRecordTestata.setNumeroRecordPresentiNelFlusso(BigInteger.valueOf(count));
					//2. scrivo il record di testata
					interchangeRecordTestata.scriviOggetto(outFile);
					//3. scrivo il frontespizio del file solo nel primo pacchetto
					if (listaOut.size()==0)
						getFrontespizio().scriviOggetto(outFile);
					//4. scrivo gli altri record nel buffer
					out.writeTo(outFile);
					//5. metto outFile in lista
					listaOut.add(outFile);
					//6. resetto i buffer
					out.close();
					outFile.close();
					//7. resetto il contatore dei record
					count=1;
					out = new ByteArrayOutputStream();
				}
				//4. scrivo l'oggetto sul buffer
				record.scriviOggetto(out);
				
				// se sono alla fine aggiungo l'ultimo outpuStream alla lista
				if (!it.hasNext()){
					ByteArrayOutputStream outFile = new ByteArrayOutputStream();
					//1. aggiorno il numero di record da inserire nel file spacchettato
					interchangeRecordTestata.setNumeroRecordPresentiNelFlusso(BigInteger.valueOf(count+1));
					//2. scrivo il record di testata
					interchangeRecordTestata.scriviOggetto(outFile);
					//3. scrivo il frontespizio del file solo nel primo pacchetto
					if (listaOut.size()==0)
						getFrontespizio().scriviOggetto(outFile);
					//4. scrivo gli altri record nel buffer
					out.writeTo(outFile);
					//5. metto outFile in lista
					listaOut.add(outFile);
					//6. resetto i buffer
					out.close();
					outFile.close();
				}
				
				outTmp.close();
				// aggiorno il contatore dei record
				count++;
			}
		} else {
			listaOut.add(appoggio);
			appoggio.close();
		}
		return listaOut; // contiene oggetti di tipo ByteArrayOutputStream della size specificata
	}
	public MetanoInterchange getInterchangeRecordTestata() {
		return interchangeRecordTestata;
	}

	public void setInterchangeRecordTestata(MetanoInterchange frontespizioInter) {
		this.interchangeRecordTestata = frontespizioInter;
		this.interchangeRecordTestata.setNumeroRecordPresentiNelFlusso(getFrontespizio().getNumeroTotaleRecord());
	}

	public ResourceAccess getResourceAccess() {
		return resourceAccess;
	}
	
	public void setResourceAccess(ResourceAccess access) {
		resourceAccess = access;
	}

}
