package it.finanze.dogane.accise.metano.model;

import it.finanze.dogane.accise.model.AbstractRecord;
import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

public class RecordFactory {

	public static final String FRONTESPIZIO_TYPE = "00";
	public static final String METANO_INTRODOTTO_IN_DEPOSITI_FISCALI = "10";
	public static final String METANO_ACQUISTATO_DA_SOGGETTI_SENZA_IMPIANTI = "11";
	//MetanoEstrattoVenduto
	public static final String METANO_ESTRATTO_VENDUTO_1 = "15";
	public static final String METANO_ESTRATTO_VENDUTO_2 = "16";
	//
	public static final String METANO_FATTURATO_IMPIEGATO_SENZA_PAGAMENTO_ACCISA = "20";
	
	public static final String METANO_FATTURATO_IMPIEGATO_1 = "31";
	public static final String METANO_FATTURATO_IMPIEGATO_2 = "32";
	
	public static final String RETTIFICHE_FATTURAZIONE = "40";
	
	public static final String METANO_LIQUIDAZIONE_IMPOSTE_1 = "50";
	public static final String METANO_LIQUIDAZIONE_IMPOSTE_2 = "60";
	public static final String METANO_LIQUIDAZIONE_IMPOSTE_3 = "70";
	
	public static final String RIEPILOGO_SALDO_IMPOSTE_1 = "55";
	public static final String RIEPILOGO_SALDO_IMPOSTE_2 = "65";
	public static final String RIEPILOGO_SALDO_IMPOSTE_3 = "75";
	public static final String DATI_ADDIZIONALE_CLIENTI_AGEVOLATI = "80";
	

	/**
	 * Ritorna un oggetto di tipo ElettricitaRecord oppure null se il file  stato letto completamente.
	 * @param is
	 * @return
	 * @throws IOException
	 */
	public static MetanoRecord readNextRecord(BufferedReader reader)
		throws IOException {

		String record = reader.readLine();
		// Questa istruzione non funzioner se vferr modificato il terminatore di file
		if (record == null) {
			return null;
		}

		record += AbstractRecord.FINERECORD;

		ByteArrayInputStream recordIS =
			new ByteArrayInputStream(record.getBytes());

		MetanoRecord metanoRecord = null;

		String tipoRecord = record.substring(19,21);
		// 19 e la posizione di una stringa di 2 caratteri che indica il tipo record

		if (tipoRecord.equals(FRONTESPIZIO_TYPE)) {
			metanoRecord = new Frontespizio();
		} else if (tipoRecord.equals(METANO_INTRODOTTO_IN_DEPOSITI_FISCALI))
			{
				metanoRecord = new MetanoIntrodottoInDepositiFiscali();
			}

		 else if (tipoRecord.equals(METANO_ACQUISTATO_DA_SOGGETTI_SENZA_IMPIANTI))
			{
				metanoRecord = new MetanoAcquistatoDaSoggettiSenzaImpianti();
			}

		 else if (
			tipoRecord.equals(METANO_ESTRATTO_VENDUTO_1)
			|| tipoRecord.equals(METANO_ESTRATTO_VENDUTO_2))
			 {
				metanoRecord = new MetanoEstrattoVenduto();
			 }

		 else if (
			tipoRecord.equals(METANO_FATTURATO_IMPIEGATO_SENZA_PAGAMENTO_ACCISA))
			 {
				metanoRecord = new MetanoFatturatoImpiegatoSenzaPagAccisa();
			 }

	     else if (
			tipoRecord.equals(METANO_FATTURATO_IMPIEGATO_1)
				|| tipoRecord.equals(METANO_FATTURATO_IMPIEGATO_2)) 
			{
				metanoRecord = new MetanoFatturatoImpiegato();
			}

		 else if (
			tipoRecord.equals(RETTIFICHE_FATTURAZIONE))
			{
				metanoRecord = new MetanoRettificheFatturazione();
			}
			
		else if (
			tipoRecord.equals(METANO_LIQUIDAZIONE_IMPOSTE_1)
			|| tipoRecord.equals(METANO_LIQUIDAZIONE_IMPOSTE_2)
			|| tipoRecord.equals(METANO_LIQUIDAZIONE_IMPOSTE_3))
			 {
				metanoRecord = new MetanoLiquidazioneImposte();
			 }
		else if (
			tipoRecord.equals(RIEPILOGO_SALDO_IMPOSTE_1)
			|| tipoRecord.equals(RIEPILOGO_SALDO_IMPOSTE_2)
			|| tipoRecord.equals(RIEPILOGO_SALDO_IMPOSTE_3))
			 {
				metanoRecord = new MetanoRiepilogoSaldoImposte();
			 }else if (
			tipoRecord.equals(DATI_ADDIZIONALE_CLIENTI_AGEVOLATI)) {

			metanoRecord = new DatiAddizionaleClientiAgevolati();

			}		

		 else {
			throw new RuntimeException("Tipo Record non riconosciuto. Tipo: " + tipoRecord);
		}

		metanoRecord.leggiOggetto(recordIS);
		recordIS.close();

		return metanoRecord;
	}

}
