package it.finanze.dogane.accise.metano.ui.tablemodel;

import it.finanze.dogane.accise.metano.model.MetanoAcquistatoDaSoggettiSenzaImpianti;
import it.finanze.dogane.accise.pdf.PrintableTableModel;

import java.math.BigInteger;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import javax.swing.table.AbstractTableModel;

public class MetanoAcquistatoDaSoggettiSenzaImpiantiTM extends AbstractTableModel implements PrintableTableModel {
	
	private List listaRecord = null;
	
	public MetanoAcquistatoDaSoggettiSenzaImpiantiTM(List lista, boolean isAnnualeToBeInitialized) {
		try {
			if(isAnnualeToBeInitialized) {
				listaRecord = aggrega(lista);
			} else {
				listaRecord = lista;
			}
		}
		catch(Exception e) {
			e.printStackTrace();
			throw new RuntimeException("Errore durante il caricamento della lista. " + e.getMessage());
		}
	}

	private List aggrega(List records) throws CloneNotSupportedException {
		BigInteger propriPozzi = BigInteger.ZERO;
		BigInteger totale = BigInteger.ZERO;
		HashMap aggregatoreNazionale = new HashMap();
		HashMap aggregatoreUE = new HashMap();
		HashMap aggregatoreExtraUE = new HashMap();
		
		if(records != null) {
			Iterator it = records.iterator();
			while(it.hasNext()) { 
				MetanoAcquistatoDaSoggettiSenzaImpianti item = (MetanoAcquistatoDaSoggettiSenzaImpianti)it.next();
				if(!item.getTipoRigo().equals(BigInteger.valueOf(9))) {
					// Mi faccio le somme di questi valori per tutti i righi
					propriPozzi = propriPozzi.add(item.getMetanoDiProprieta());
					totale = totale.add(item.getTotale());
				
					// Aggrego per nazionale
					MetanoAcquistatoDaSoggettiSenzaImpianti aggregato = aggrega(aggregatoreNazionale, item, item.getCodiceAccisaFornitoreNazionale());
					aggregato.setCodiceAccisaFornitoreUE("");
					aggregato.setMetanoFornitoreUE(BigInteger.ZERO);
					aggregato.setStatoEsteroMetanoFornitoreExtraUE("");
					aggregato.setMetanoFornitoreExtraUE(BigInteger.ZERO);
				
					// Aggrego per UE
					aggregato = aggrega(aggregatoreUE, item, item.getCodiceAccisaFornitoreUE());
					aggregato.setCodiceAccisaFornitoreNazionale("");
					aggregato.setMetanoFornitoreNazionale(BigInteger.ZERO);
					aggregato.setStatoEsteroMetanoFornitoreExtraUE("");
					aggregato.setMetanoFornitoreExtraUE(BigInteger.ZERO);

					// Aggrego per ExtraUE
					aggregato = aggrega(aggregatoreExtraUE, item, item.getStatoEsteroMetanoFornitoreExtraUE());
					aggregato.setCodiceAccisaFornitoreNazionale("");
					aggregato.setMetanoFornitoreNazionale(BigInteger.ZERO);
					aggregato.setCodiceAccisaFornitoreUE("");
					aggregato.setMetanoFornitoreUE(BigInteger.ZERO);
				}
			}
		}

		// Ora posso costruire la lista di ritorno con il primo valore pari al punto di ingresso
		LinkedList retlist = new LinkedList(aggregatoreNazionale.values());
		retlist.addAll(aggregatoreUE.values());
		retlist.addAll(aggregatoreExtraUE.values());
		
		MetanoAcquistatoDaSoggettiSenzaImpianti primo = (MetanoAcquistatoDaSoggettiSenzaImpianti)retlist.getFirst();
		primo.setTipoRigo(BigInteger.ZERO);
		primo.setMetanoDiProprieta(propriPozzi);
		primo.setTotale(totale);

		return retlist;
	}

	private MetanoAcquistatoDaSoggettiSenzaImpianti aggrega(HashMap aggregatore, MetanoAcquistatoDaSoggettiSenzaImpianti item, String chiave) throws CloneNotSupportedException {

		MetanoAcquistatoDaSoggettiSenzaImpianti aggregato = (MetanoAcquistatoDaSoggettiSenzaImpianti)aggregatore.get(chiave);
		if(aggregato == null) {
			aggregato = (MetanoAcquistatoDaSoggettiSenzaImpianti)item.clone();
			aggregato.setTipoRigo(BigInteger.ONE);
			aggregato.setMetanoDiProprieta(BigInteger.ZERO);
			aggregato.setTotale(BigInteger.ZERO);
			aggregato.setMese(BigInteger.ZERO);
			aggregatore.put(chiave, aggregato);
		} else {
			aggregato.setMetanoFornitoreNazionale(aggregato.getMetanoFornitoreNazionale().add(item.getMetanoFornitoreNazionale()));
			aggregato.setMetanoFornitoreUE(aggregato.getMetanoFornitoreUE().add(item.getMetanoFornitoreUE()));
			aggregato.setMetanoFornitoreExtraUE(aggregato.getMetanoFornitoreExtraUE().add(item.getMetanoFornitoreExtraUE()));
		}
		
		return aggregato;
	}


	public Object getValueAt(int rowIndex, int columnIndex) {
		MetanoAcquistatoDaSoggettiSenzaImpianti record = (MetanoAcquistatoDaSoggettiSenzaImpianti)listaRecord.get(rowIndex);
		
			Object retvalue = null;
			if(columnIndex == 0) {
				if(rowIndex == 0) {
					retvalue = record.getMetanoDiProprieta();	       
				} else {
					retvalue = "";
				}
			} else if(columnIndex == 1) {
			  retvalue = record.getCodiceAccisaFornitoreNazionale();
			} else if(columnIndex == 2) {
				retvalue = record.getMetanoFornitoreNazionale();
			} else if(columnIndex == 3) {
				retvalue = record.getCodiceAccisaFornitoreUE();
			} else if(columnIndex == 4) {
		       retvalue = record.getMetanoFornitoreUE();
	        } else if(columnIndex == 5) {
		       retvalue = record.getStatoEsteroMetanoFornitoreExtraUE();
			} else if(columnIndex == 6) {
			  retvalue = record.getMetanoFornitoreExtraUE();	       
			} else if(columnIndex == 7) {
				if(rowIndex == 0) {
					retvalue = record.getTotale();	       
				} else {
					retvalue = "";
				}
	  		}
	         
		return retvalue;
	}

	public int getColumnCount() {
		return 8;
	}

	public int getRowCount() {
		return listaRecord.size();
	}
	
	public String getColumnName(int columnIndex) {
		String retvalue = null;
		if (columnIndex == 0) {
			retvalue = "Di propriet";
		} else if (columnIndex == 1) {
			retvalue = "Codice identificativo";
		} else if (columnIndex == 2) {
			retvalue = "Metri cubi";
		} else if (columnIndex == 3) {
			retvalue = "Codice identificativo";
		} else if (columnIndex == 4) {
			retvalue = "Metri cubi";
		} else if (columnIndex == 5) {
			retvalue = "Stato estero";
		} else if (columnIndex == 6) {
			retvalue = "Metri cubi";
		} else if (columnIndex == 7) {
			retvalue = "Totale";
		}
		
		return retvalue;
	}

	public MetanoAcquistatoDaSoggettiSenzaImpianti getRecord(int selectedRow) {
		return (MetanoAcquistatoDaSoggettiSenzaImpianti) listaRecord.get(selectedRow);
	}

	public List getRecords() {
		return listaRecord;
	}

	public void insertRecord(MetanoAcquistatoDaSoggettiSenzaImpianti record) {
		if(listaRecord.size() == 0) {
			record.setTipoRigo(BigInteger.valueOf(0));
		} else {
			record.setTipoRigo(BigInteger.valueOf(1));
		}
		
		listaRecord.add(record);
			
		updateFirstRecordTot();

		this.fireTableRowsInserted(getRowCount() -1 , getRowCount() - 1);
		this.fireTableDataChanged();
	}

	public void removeRecord(int selectedRow) {
				
		if(selectedRow == 0 && listaRecord.size() > 1) {
			MetanoAcquistatoDaSoggettiSenzaImpianti nextRecord = (MetanoAcquistatoDaSoggettiSenzaImpianti)listaRecord.get(selectedRow + 1);
			nextRecord.setTipoRigo(BigInteger.valueOf(0));
		}
		listaRecord.remove(selectedRow);
		
		updateFirstRecordTot();

		this.fireTableRowsDeleted(selectedRow, selectedRow);
		this.fireTableDataChanged();
	}
	

	public void setRecord(int selectedRow, MetanoAcquistatoDaSoggettiSenzaImpianti record) {
		
		
		if(selectedRow == 0) {
			record.setTipoRigo(BigInteger.valueOf(0));
		} else {
			record.setTipoRigo(BigInteger.valueOf(1));
		}
		listaRecord.set(selectedRow, record);
		
		updateFirstRecordTot();

		this.fireTableDataChanged();
	}

	private void updateFirstRecordTot() {
		BigInteger totale = BigInteger.ZERO;
		if(listaRecord != null && listaRecord.size() > 0) {
			Iterator it = listaRecord.iterator();
			while(it.hasNext()) {
				MetanoAcquistatoDaSoggettiSenzaImpianti item = (MetanoAcquistatoDaSoggettiSenzaImpianti)it.next();

				totale = totale.add(item.getMetanoFornitoreExtraUE());
				totale = totale.add(item.getMetanoFornitoreNazionale());
				totale = totale.add(item.getMetanoFornitoreUE());
				totale = totale.add(item.getMetanoDiProprieta());
			}
			
			MetanoAcquistatoDaSoggettiSenzaImpianti firstItem = (MetanoAcquistatoDaSoggettiSenzaImpianti)listaRecord.get(0);
			firstItem.setTotale(totale);
		}
	}

	public PrintableTableModel split(int index, int offset) {
		List newListaRecord = new LinkedList();
		
		Iterator it = listaRecord.iterator();
		int i = 0;
		while(it.hasNext()) {
			Object obj = it.next();
			if(i>=index && i<=index+offset-1) {
				newListaRecord.add(obj);
			}
			i++;
		}
		
		return new MetanoAcquistatoDaSoggettiSenzaImpiantiTM(newListaRecord, false);
	}

	public PrintableTableModel split(int index) {
		return split(index, listaRecord.size() - index);
	}

}
