package it.finanze.dogane.accise.metano.ui.tablemodel;

import it.finanze.dogane.accise.metano.model.MetanoFatturatoImpiegatoSenzaPagAccisa;
import it.finanze.dogane.accise.pdf.DefaultPrintableTableModel;
import it.finanze.dogane.accise.pdf.PrintableTableModel;

import java.math.BigInteger;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import javax.swing.table.AbstractTableModel;

public class MetanoFatturatoImpiegatoSenzaPagAccisaTM
	extends AbstractTableModel implements PrintableTableModel {

	private List listaRecord = new LinkedList();

	private boolean annuale = false;

	public static final String[] QUADRO_E_DESCRIPTION =
		{
			"Impieghi diversi da carbur. per motori o da comb. per risc. fino al 31/05/2007 ",
			"Prosciugamento e sistemazione terreni allagati nelle zone colpite da alluvione",
			"Sollevamento acque per agevolazione coltivazione fondi rustici su terreni bonificati",
			"Produzione di ossido di alluminio (fino al 31/05/2007) e di magnesio da acqua di mare",
			"Prodotti energetici iniettati negli altiforni per realizz. processi produttivi ",
			"Forniture rel. dipl. a org. int. ric., a FF. AA. NATO, in accordo con esenzione IVA",
			"Forniture alle Forze Armate naizonali",
			"Usi di cantiere e operaz. di campo per coltivaz. idroc. fino al 31/05/2007",
			"Impieghi diversi da carb. per motori o da comb. per riscald. dal 01/06/2007 ",
			"Articolo 22 del D. Lgs. 504/95- usi interni di raffineria",
			"Esportazione",
			"Prodotti energetici utilizzati per la riduzione chimica ",
			"Prodotti energetici utilizzati nei processi elettrolitici ",
			"Prodotti energetici utilizzati nei processi metallurgici ",
			"Prodotti energetici utilizzati nei processi mineralogici ",
			"TOTALE" };

	public static final int[] QUADRO_E_IDENTIFIERS =
		{ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 ,13,14,15,16};

	private String[] descriptions = null;
	private int[] identifiers = null;

	public MetanoFatturatoImpiegatoSenzaPagAccisaTM(List lista,String mese) {

		if (mese.equals("Annuale")) {
			annuale = true;
		}

		descriptions = QUADRO_E_DESCRIPTION;
		identifiers = QUADRO_E_IDENTIFIERS;

		for (int i = 0; i < descriptions.length; i++) {
			listaRecord.add(null);
		}

		Iterator it = lista.iterator();
		while (it.hasNext()) {
			MetanoFatturatoImpiegatoSenzaPagAccisa record =
				(MetanoFatturatoImpiegatoSenzaPagAccisa) it.next();
			record.getLetteraIdQuadro();
			int row = computeRow(record.getProgIdRigo());

			if (row != -1) {
				listaRecord.set(row, record);

			}

		}

	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		MetanoFatturatoImpiegatoSenzaPagAccisa record =	(MetanoFatturatoImpiegatoSenzaPagAccisa) listaRecord.get(rowIndex);
		Object retvalue = null;
		
		if(annuale!=true && columnIndex == 2){
					columnIndex++;
		}

		if (record == null) {
			if (columnIndex == 0) {
				retvalue = new Integer(identifiers[rowIndex]);
			} else if (columnIndex == 1) {
				retvalue = descriptions[rowIndex];
			} else if (columnIndex == 2) {
				retvalue = "";
			} else if (columnIndex == 3) {
				retvalue = "";
			}

		} else {
			if (columnIndex == 0) {
				retvalue = record.getProgIdRigo();
			} else if (columnIndex == 1) {
				retvalue = descriptions[rowIndex];
			} else if (columnIndex == 2) {
				if (record.getNumUtenze().equals(BigInteger.valueOf(000000000)))
					retvalue = "";
				else {
					retvalue = record.getNumUtenze();
				}
			} else if (columnIndex == 3) {
				retvalue = record.getQuantita();
			}

		}

		return retvalue;
	}

	public int getColumnCount() {
		if(annuale== true){		
			return 4;
		}else {		
		    return 3;
		}
		
	}

	public int getRowCount() {
		return listaRecord.size();
	}

	public String getColumnName(int columnIndex) {

		String retvalue = null;
		
		if(annuale!=true && columnIndex == 2){
			columnIndex++;
		}
		
		if (columnIndex == 0) {
			retvalue = "";			
		} else if (columnIndex == 1) {
			retvalue = "";
			
		} else if (columnIndex == 2) {
			retvalue = "Numero utenze al 1 gennaio";			
		 
		} else if (columnIndex == 3) {
			retvalue = "Quantit metri cubi";
		}

		return retvalue;
	}

	public MetanoFatturatoImpiegatoSenzaPagAccisa getRecord(int selectedRow) {
		return (MetanoFatturatoImpiegatoSenzaPagAccisa) listaRecord.get(
			selectedRow);
	}

	public void setRecord(
		int selectedRow,
		MetanoFatturatoImpiegatoSenzaPagAccisa record) {
		listaRecord.set(selectedRow, record);
		if (record != null) {
			record.setProgIdRigo(BigInteger.valueOf(identifiers[selectedRow]));
		}

		this.fireTableRowsUpdated(selectedRow, selectedRow);
	}

	public void removeRecord(int selectedRow) {
		setRecord(selectedRow, null);
	}

	public List getRecords() {
		List retlist = new LinkedList();
		Iterator it = listaRecord.iterator();
		while (it.hasNext()) {
			Object obj = it.next();
			if (obj != null) {
				retlist.add(obj);
			}
		}
		return retlist;
	}

	private int computeRow(BigInteger identifier) {
		for (int i = 0; i < identifiers.length; i++) {
			if (identifier.equals(BigInteger.valueOf(identifiers[i]))) {
				return i;
			}
		}
		return -1; // E quindi crasha!!!!!! 
	}

	public PrintableTableModel split(int index, int offset) {
		return DefaultPrintableTableModel.getSplitted(this, index, offset);
		//throw new UnsupportedOperationException();
	}

	public PrintableTableModel split(int index) {
		return split(index, listaRecord.size() - index);
	}

}
