package it.finanze.dogane.accise.metano.ui.tablemodel;

import it.finanze.dogane.accise.metano.model.MetanoFatturatoImpiegato;
import it.finanze.dogane.accise.metano.ui.quadri.Quadro;
import it.finanze.dogane.accise.pdf.DefaultPrintableTableModel;
import it.finanze.dogane.accise.pdf.PrintableTableModel;

import java.math.BigInteger;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import javax.swing.table.AbstractTableModel;

public class MetanoFatturatoImpiegatoTM extends AbstractTableModel implements PrintableTableModel {

	private List listaRecord = new LinkedList();
	private boolean annuale = false;

	public static final String[] QUADRO_F_DESCRIPTION =
		{
			"Usi industriali" ,
			"Utenze Centro-Nord - Usi civili tariffa T1" ,
			"Utenze Centro-Nord - Usi civili tariffa T2 fino a 250 mc/anno" ,
			"Utenze Centro-Nord - Usi civili tariffa T2 oltre 250 mc/anno e altri usi civili" ,
			"Utenze mezzogiorno - Usi civili tariffa T1" ,
			"Utenze mezzogiorno - Usi civili tariffa T2 fino a 250 mc/anno" ,
			"Utenze mezzogiorno - Usi civili tariffa T2 oltre 250 mc/anno e altri usi civili" ,
			"" ,
			""
			};	

	public static final int[] QUADRO_F_IDENTIFIERS =
		{ 1, 2, 3, 4, 5, 6, 7, 8, 9};


	public static final String[] QUADRO_G_DESCRIPTION =
		{
			"Usi industriali" ,
			"Utenze Centro-Nord - Usi civili tariffa T1" ,
			"Utenze Centro-Nord - Usi civili tariffa T2 fino a 250 mc/anno" ,
			"Utenze Centro-Nord - Usi civili tariffa T2 oltre 250 mc/anno e altri usi civili" ,
			"Utenze mezzogiorno - Usi civili tariffa T1" ,
			"Utenze mezzogiorno - Usi civili tariffa T2 fino a 250 mc/anno" ,
			"Utenze mezzogiorno - Usi civili tariffa T2 oltre 250 mc/anno e altri usi civili" ,
			"Produzione di energia elettrica" ,
			"Autoproduzione di energia elettrica",
			"Autotrazione",
			"Usi di cantiere, motori fissi e operaz. di campo coltivaz. idroc. dal 01/06/2007"
			
			};	

	public static final int[] QUADRO_G_IDENTIFIERS =
		{ 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11};
	
	private String[] descriptions = null;
	private int[] identifiers = null;

	public MetanoFatturatoImpiegatoTM(List lista,int[] tipiRecord,String mese)
	 {

		if (mese.equals("Annuale")) {
			annuale = true;
		}

		if (Quadro.QUADRO_F.equals(tipiRecord)) {
			descriptions = QUADRO_F_DESCRIPTION;
			identifiers = QUADRO_F_IDENTIFIERS;
		}
		else if (Quadro.QUADRO_G.equals(tipiRecord)) {
			descriptions = QUADRO_G_DESCRIPTION;
			identifiers = QUADRO_G_IDENTIFIERS;
		 } else {
			 throw new IllegalArgumentException("Tipo record " + tipiRecord.toString().trim() + " non consentito. (Quadri permessi F,G)");
		 }


		for (int i = 0; i < descriptions.length; i++) {
			listaRecord.add(null);
		}
			

		Iterator it = lista.iterator();
		while (it.hasNext()) {
			MetanoFatturatoImpiegato record =(MetanoFatturatoImpiegato) it.next();
			record.getLetteraIdQuadro();
			int row = computeRow(record.getProgIdRigo());
			
			if (row != -1) {
			   listaRecord.set(row, record);
			}			
		}
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		MetanoFatturatoImpiegato record =(MetanoFatturatoImpiegato) listaRecord.get(rowIndex);
		Object retvalue = null;
		
		if(annuale!=true && columnIndex == 2){
							columnIndex++;
				}

		if (record == null) {
			if (columnIndex == 0) {
				retvalue = new Integer(identifiers[rowIndex]);
			} else if (columnIndex == 1) {
				retvalue = descriptions[rowIndex];
			} else if (columnIndex == 2) {
				retvalue = "";	
			} else if (columnIndex == 3) {
				retvalue = "";			
		}
			
		} else {
			if (columnIndex == 0) {
				retvalue = record.getProgIdRigo();
			} else if (columnIndex == 1) {
				retvalue = descriptions[rowIndex];
			} else if (columnIndex == 2) {
				retvalue =  record.getNumUtenze();
			}else if (columnIndex == 3) {
			retvalue =  record.getQuantita();
		}						
		}

		return retvalue;
	}

	public int getColumnCount() {
		if(annuale==true){		
			return 4;
		}else return 3;
	}

	public int getRowCount() {
		return listaRecord.size();
	}

	public String getColumnName(int columnIndex) {
		String retvalue = null;
		if(annuale!=true && columnIndex == 2){
							columnIndex++;
		}
		if (columnIndex == 0) {
			retvalue = "";
		} else if (columnIndex == 1) {
			retvalue = "";
		}else if (columnIndex == 2) {
			retvalue = "Numero utenze al 1 gennaio";
		} else if (columnIndex == 3) {
			retvalue = "Quatit metri cubi";
		}
		

		return retvalue;
	}

	public MetanoFatturatoImpiegato getRecord(int selectedRow) {
		return (MetanoFatturatoImpiegato) listaRecord.get(selectedRow);
	}

	public void setRecord(int selectedRow, MetanoFatturatoImpiegato record) {
		listaRecord.set(selectedRow, record);
		if (record != null) {
			record.setProgIdRigo(BigInteger.valueOf(identifiers[selectedRow]));
		}

		this.fireTableRowsUpdated(selectedRow, selectedRow);
	}

	public void removeRecord(int selectedRow) {
		setRecord(selectedRow, null);
	}

	public List getRecords() {
		List retlist = new LinkedList();
		Iterator it = listaRecord.iterator();
		while (it.hasNext()) {
			Object obj = it.next();
			if (obj != null) {
				retlist.add(obj);
			}
		}
		return retlist;
	}

	private int computeRow(BigInteger identifier) {
		for (int i = 0; i < identifiers.length; i++) {
			if (identifier.equals(BigInteger.valueOf(identifiers[i]))) {
				return i;
			}
		}
		return -1; // E quindi crasha!!!!!! 
	}

	public PrintableTableModel split(int index, int offset) {
		return DefaultPrintableTableModel.getSplitted(this, index, offset);
		//throw new UnsupportedOperationException();
	}

	public PrintableTableModel split(int index) {
		return split(index, listaRecord.size() - index);
	}

}
