package it.finanze.dogane.accise.metano.ui.tablemodel;



import it.finanze.dogane.accise.combo.TipoMese;
import it.finanze.dogane.accise.metano.model.MetanoIntrodottoInDepositiFiscali;

import java.math.BigInteger;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;

import javax.swing.table.AbstractTableModel;

public class MetanoIntrodottoInDepositiFiscaliPuntiImmissioneTM
	extends AbstractTableModel {

	private LinkedHashMap map = new LinkedHashMap();
	private TipoMese tipoMese = null;

	public MetanoIntrodottoInDepositiFiscaliPuntiImmissioneTM(List lista, TipoMese tipoMese) {
		this.tipoMese = tipoMese;
		List listaPuntiDiImmissione = findPuntiImmissione(lista);
		if(tipoMese != null) {
			if(Integer.parseInt(tipoMese.getCodice()) == 0) { // Annuale
				loadMapAnnuale(lista, listaPuntiDiImmissione);
			} else {
				loadMap(tipoMese, listaPuntiDiImmissione);
			}
		} else {
			loadMap(lista, listaPuntiDiImmissione);
		}
	}

	private List findPuntiImmissione(List lista){
	   List retlist = new LinkedList();
	   if (lista != null) {
		   Iterator it = lista.iterator();						
		   while (it.hasNext()) {		
			   MetanoIntrodottoInDepositiFiscali record =(MetanoIntrodottoInDepositiFiscali) it.next();						
			   if (record.getTipoRigo().equals(BigInteger.valueOf(0))) {							
				   retlist.add(record);
			   }
		   }
	   }
	   return retlist;	 	
	}

	private void loadMapAnnuale(List lista, List listaPuntiDiImmissione) {
		loadMap(lista, listaPuntiDiImmissione);
		LinkedHashMap tmpMap = map;
		// map = new LinkedHashMap();
		
		try {
			Object[] keys = tmpMap.keySet().toArray();
			for(int i = 0; i < keys.length; i++) {
				MetanoIntrodottoInDepositiFiscali punto = (MetanoIntrodottoInDepositiFiscali)keys[i];

				List records = (List)tmpMap.get(punto);
				records = aggrega(records, i + 1);
			
				map.put(records.get(0), records);
			}
		}
		catch(Exception e) {
			e.printStackTrace();
			throw new RuntimeException("Errore durante il caricamento della lista. " + e.getMessage());
		}
		
	}


	private List aggrega(List records, int progressivo) throws CloneNotSupportedException {
		BigInteger propriPozzi = BigInteger.ZERO;
		BigInteger altreFonti = BigInteger.ZERO;
		BigInteger extraUE = BigInteger.ZERO;
		BigInteger totale = BigInteger.ZERO;
		HashMap aggregatoreNazionale = new HashMap();
		HashMap aggregatoreUE = new HashMap();
		String comune = null;
		String provincia = null;
		String indirizzo = null;
		
		if(records != null) {
			Iterator it = records.iterator();
			while(it.hasNext()) { 
				MetanoIntrodottoInDepositiFiscali item = (MetanoIntrodottoInDepositiFiscali)it.next();
				
				// Se si tratta di uno dei punti di immissione mi metto le info relative da parte
				if(item.getTipoRigo().equals(BigInteger.ZERO)) {
					comune = item.getComunePuntoImmissione();
					provincia = item.getProvinciaPuntoImmissione();
					indirizzo = item.getIndirizzoPuntoImmissione();
				}
				
				// Mi faccio le somme di questi valori per tutti i righi
				propriPozzi = propriPozzi.add(item.getMetanoPropriPozzi());
				altreFonti = altreFonti.add(item.getMetanoAltreFonti());
				extraUE = extraUE.add(item.getMetanoFornitoreExtraUE());
				totale = totale.add(item.getTotale());
				
				// Aggrego per nazionale
				MetanoIntrodottoInDepositiFiscali aggregato = aggrega(aggregatoreNazionale, item, progressivo, item.getCodiceAccisaFornitoreNazionale());
				aggregato.setCodiceAccisaFornitoreUE("");
				aggregato.setMetanoFornitoreUE(BigInteger.ZERO);
				
				// Aggrego per UE
				aggregato = aggrega(aggregatoreUE, item, progressivo, item.getCodiceAccisaFornitoreUE());
				aggregato.setCodiceAccisaFornitoreNazionale("");
				aggregato.setMetanoFornitoreNazionale(BigInteger.ZERO);
			}
		}

		// Ora posso costruire la lista di ritorno con il primo valore pari al punto di ingresso
		LinkedList retlist = new LinkedList(aggregatoreNazionale.values());
		retlist.addAll(aggregatoreUE.values());
		
		MetanoIntrodottoInDepositiFiscali punto = (MetanoIntrodottoInDepositiFiscali)retlist.getFirst();
		punto.setTipoRigo(BigInteger.ZERO);
		punto.setComunePuntoImmissione(comune);
		punto.setIndirizzoPuntoImmissione(indirizzo);
		punto.setProvinciaPuntoImmissione(provincia);
		punto.setMetanoPropriPozzi(propriPozzi);
		punto.setMetanoAltreFonti(altreFonti);
		punto.setMetanoFornitoreExtraUE(extraUE);
		punto.setTotale(totale);

		return retlist;
	}

	private MetanoIntrodottoInDepositiFiscali aggrega(HashMap aggregatore, MetanoIntrodottoInDepositiFiscali item, int progressivo, String chiave) throws CloneNotSupportedException {
		// Aggrego per nazionale
		MetanoIntrodottoInDepositiFiscali aggregato = (MetanoIntrodottoInDepositiFiscali)aggregatore.get(chiave);
		if(aggregato == null) {
			aggregato = (MetanoIntrodottoInDepositiFiscali)item.clone();
			aggregato.setProgPuntoImmissione(BigInteger.valueOf(progressivo));
			aggregato.setTipoRigo(BigInteger.ONE);
			aggregato.setMetanoPropriPozzi(BigInteger.ZERO);
			aggregato.setMetanoAltreFonti(BigInteger.ZERO);
			aggregato.setMetanoFornitoreExtraUE(BigInteger.ZERO);
			aggregato.setTotale(BigInteger.ZERO);
			aggregato.setMese(BigInteger.ZERO);
			aggregatore.put(chiave, aggregato);
		} else {
			aggregato.setMetanoFornitoreNazionale(aggregato.getMetanoFornitoreNazionale().add(item.getMetanoFornitoreNazionale()));
			aggregato.setMetanoFornitoreUE(aggregato.getMetanoFornitoreUE().add(item.getMetanoFornitoreUE()));
		}
		
		return aggregato;
	}


	private void loadMap(List lista, List listaPuntiDiImmissione) {
		Iterator itPuntiImmissione = listaPuntiDiImmissione.iterator();
		while (itPuntiImmissione.hasNext()) {		
			MetanoIntrodottoInDepositiFiscali punto =(MetanoIntrodottoInDepositiFiscali) itPuntiImmissione.next();
			List sottolista = null;
			sottolista = findRecordPerPunto(lista, punto);
			sottolista.add(0, punto); //Aggiungo in testa il punto
			
			List precedente = (List)map.get(punto);
			if(precedente != null) {
				sottolista.addAll(precedente);
			}
			
			map.put(punto, sottolista);
		}
	}

	private void loadMap(TipoMese tipoMese, List listaPuntiDiImmissione) {
		Iterator itPuntiImmissione = listaPuntiDiImmissione.iterator();
		while (itPuntiImmissione.hasNext()) {		
			MetanoIntrodottoInDepositiFiscali punto =(MetanoIntrodottoInDepositiFiscali) itPuntiImmissione.next();
			map.put(punto, null);
			int mese = Integer.parseInt(tipoMese.getCodice());
			punto.setMese(BigInteger.valueOf(mese));
		}
		Object[] keys = map.keySet().toArray(); 
		for(int i = 0; i < keys.length; i++) {
			MetanoIntrodottoInDepositiFiscali punto = (MetanoIntrodottoInDepositiFiscali)keys[i];
			punto.setProgPuntoImmissione(BigInteger.valueOf(i+1));
		}
	}

	private List findRecordPerPunto(List lista, MetanoIntrodottoInDepositiFiscali punto) {
		List retlist = new LinkedList();
		if (lista != null) {
			Iterator it = lista.iterator();						
			while (it.hasNext()) {		
				MetanoIntrodottoInDepositiFiscali record =(MetanoIntrodottoInDepositiFiscali) it.next();						
				if (record.getTipoRigo().equals(BigInteger.valueOf(1)) && 
					record.getProgPuntoImmissione().equals(punto.getProgPuntoImmissione()) &&
					record.getMese().equals(punto.getMese())) {
						
					retlist.add(record);
				}
			}
		}
		return retlist;	 	
	}


	public Object getValueAt(int rowIndex, int columnIndex) {
		Object[] keys = map.keySet().toArray(); 
		
		MetanoIntrodottoInDepositiFiscali record = (MetanoIntrodottoInDepositiFiscali)keys[rowIndex];
		Object retvalue = null;		
			
			if (columnIndex == 0) {
				retvalue = record.getComunePuntoImmissione();
			} else if (columnIndex == 1) {
				retvalue = record.getProvinciaPuntoImmissione();
			} else if (columnIndex == 2) {
				retvalue = record.getIndirizzoPuntoImmissione();
			}

		
		return retvalue;
	}

	public int getColumnCount() {
		return 3;
	}

	public int getRowCount() {
		return map.keySet().size();
	}

	public String getColumnName(int columnIndex) {
		String retvalue = null;
		if (columnIndex == 0) {
			retvalue = "Comune";
		} else if (columnIndex == 1) {
			retvalue = "Provincia";
		} else if (columnIndex == 2) {
			retvalue = "Indirizzo";
		}

		return retvalue;
	}

	public List getListForPunto(int selectedRow) {
		if(selectedRow != -1) {
			Object[] keys = map.keySet().toArray(); 
			MetanoIntrodottoInDepositiFiscali punto = (MetanoIntrodottoInDepositiFiscali)keys[selectedRow];
		
			return (List)map.get(punto);
		}
		return null;
	}

	public void setListForPunto(int selectedRow, List list) {
		if(selectedRow != -1) {
			Object[] keys = map.keySet().toArray(); 
			MetanoIntrodottoInDepositiFiscali punto = (MetanoIntrodottoInDepositiFiscali)keys[selectedRow];
		
			map.put(punto, list);
		}
		// this.fireTableDataChanged();
	}
	
	public void insertPunto(MetanoIntrodottoInDepositiFiscali punto) {
		
		punto.setProgPuntoImmissione(BigInteger.valueOf(map.size() + 1)); // Prendo il prossimo progressivo
		
//		List lista = new LinkedList();
//		lista.add(punto);
//		map.put(punto, lista);
		map.put(punto, null);
		this.fireTableRowsInserted(getRowCount() - 1, getRowCount() - 1);
		this.fireTableDataChanged();
	}

	public MetanoIntrodottoInDepositiFiscali getPunto(int selectedRow) {
		Object[] keys = map.keySet().toArray(); 
		MetanoIntrodottoInDepositiFiscali punto = (MetanoIntrodottoInDepositiFiscali)keys[selectedRow];

		return punto;
	}

	/**
	 * @param selectedRow
	 */
	public void removePunto(int selectedRow) {
		Object[] keys = map.keySet().toArray(); 
		MetanoIntrodottoInDepositiFiscali punto = (MetanoIntrodottoInDepositiFiscali)keys[selectedRow];

		map.remove(punto);
		
		// Aggiusto il progressivo...
		BigInteger progressivo = punto.getProgPuntoImmissione();
		keys = map.keySet().toArray();
		for(int i = 0; i < keys.length; i++) {
			MetanoIntrodottoInDepositiFiscali unPunto = (MetanoIntrodottoInDepositiFiscali)keys[i];
			if(unPunto.getProgPuntoImmissione().compareTo(progressivo) > 0) {
				List list = (List)map.get(keys[i]);
				if(list != null) {
					Iterator it = list.iterator();
					// Sottraggo uno... e imposto a tutti gli elementi della lista
					BigInteger nuovoProgressivo = unPunto.getProgPuntoImmissione().subtract(BigInteger.valueOf(-1));
					while(it.hasNext()) {
						MetanoIntrodottoInDepositiFiscali record = (MetanoIntrodottoInDepositiFiscali)it.next();
						record.setProgPuntoImmissione(nuovoProgressivo); 
					}
				}
			}
		}
		
		
		this.fireTableRowsDeleted(selectedRow, selectedRow);		
		this.fireTableDataChanged();
	}

	public List getListaRecords() {
		List retlist = new LinkedList();
		Object[] keys = map.keySet().toArray(); 
		for(int i = 0; i < keys.length; i++) {
			List sublist = (List)map.get(keys[i]);
			if(sublist != null && sublist.size() > 0) {
				retlist.addAll(sublist);
			}
		}

		return retlist;
	}

	
}
